@@ -27,7 +27,20 @@
 namespace Lum {
   namespace Base {
 
-    extern LUMAPI int RoundRange(int x, int a, int b);
+    template<typename A>
+    A RoundRange(const A& value, const A& min, const A& max)
+    {
+      if (value<min) {
+        return min;
+      }
+      else if (value>max) {
+        return max;
+      }
+      else {
+        return value;
+      }
+    }
+
     extern LUMAPI int RoundDiv(int a,int b);
     extern LUMAPI int RoundUpEven(int a);
     extern LUMAPI int UpDiv(int a, int b);
