@@ -33,7 +33,8 @@ namespace Lum {
     Placeholder();
 
     void CalcSize();
-    void Draw(int x, int y, size_t w, size_t h);
+
+    static Placeholder* Create(bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
