@@ -33,14 +33,6 @@ namespace Lum {
   */
   class LUMAPI RGBControl : public ControlComponent
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   private:
     Model::IntRef   r;
     Model::IntRef   g;
