@@ -281,8 +281,8 @@ namespace Lum {
 
   private:
     Type                          type;
-    Model::ActionRef              colonAction;
-    std::vector<Model::ActionRef> digitActions;
+    Model::ActionRef              colonAction;  // Obsolete!
+    std::vector<Model::ActionRef> digitActions; // Obsolete!
 
   public:
     InputHelperNumber(Type type);
