@@ -45,9 +45,9 @@ namespace Lum {
     Model::ActionRef  doubleClickAction;
 
   private:
+    void UpdateDimensions();
     bool GetClickedEntryPos(int y, size_t& pos);
     void DrawItem(OS::DrawInfo* draw, Model::Tree::Item* item, size_t y, size_t offset);
-    void DrawTree();
 
   public:
     Tree();
