@@ -257,12 +257,14 @@ namespace Lum {
 
       vPanel=VPanel::Create(true,true);
 
-      dirSel=new DirSelect();
-      dirSel->SetFlex(true,false);
-      dirSel->SetModel(path);
-      vPanel->Add(dirSel);
+      if (!Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+        dirSel=new DirSelect();
+        dirSel->SetFlex(true,false);
+        dirSel->SetModel(path);
+        vPanel->Add(dirSel);
 
-      vPanel->AddSpace();
+        vPanel->AddSpace();
+      }
 
       header=new Model::HeaderImpl();
       header->AddColumn(_l(L"MODEL_DIR_FILENAME",L"Filename"),Base::Size::stdCharWidth,15,true);
@@ -272,7 +274,7 @@ namespace Lum {
       table=new Table();
       table->SetFlex(true,true);
       table->SetMinWidth(Base::Size::stdCharWidth,40);
-      table->SetShowHeader(true);
+      table->SetShowHeader(!Lum::OS::display->GetTheme()->RequestFingerFriendlyControls());
       table->GetTableView()->SetAutoFitColumns(true);
       table->GetTableView()->SetAutoHSize(true);
       table->SetSelection(selection);
@@ -283,7 +285,10 @@ namespace Lum {
 
       popup=new Menu();
       popup->SetParent(GetWindow());
-      popup->AddBoolItem(_l(L"DLG_FILE_SHOW_HIDDEN",L"Show _hidden files"),showHidden,OS::qualifierControl,L"h");
+      popup->AddBoolItem(_l(L"DLG_FILE_SHOW_HIDDEN",
+                            L"Show _hidden files"),
+                            showHidden,
+                            OS::qualifierControl,L"h");
       table->SetMenu(popup->GetWindow());
 
       vPanel->Add(table);
@@ -291,11 +296,17 @@ namespace Lum {
 
       hPanel=HPanel::Create(true,false);
 
-      locations=Button::Create(_l(L"DLG_FILE_LOCATIONS",L"_Locations"),locationsAction,false,true);
-      hPanel->Add(locations);
+      if (!Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+        locations=Button::Create(_l(L"DLG_FILE_LOCATIONS",L"_Locations"),
+                                 locationsAction,false,true);
+        hPanel->Add(locations);
+      }
+
       hPanel->AddSpace(true);
 
-      if (options->filters.size()>0) {
+      if (options->filters.size()>0 &&
+          (!Lum::OS::display->GetTheme()->RequestFingerFriendlyControls() ||
+           options->filters.size()>1)) {
         Combo              *combo;
         Model::StringTable *filters;
 
@@ -316,16 +327,22 @@ namespace Lum {
 
       hPanel=HPanel::Create(true,false);
 
+      if (Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+        hPanel->Add(Button::Create(_l(L"DLG_FILE_UP",L".."),parentAction,false,true));
+      }
+
       fullStr=String::Create(full,true,false);
       fullStr->SetReturnAction(fullAction);
       hPanel->Add(fullStr);
 
-      hPanel->Add(Button::Create(_l(L"DLG_FILE_RELOAD",L"_Reload"),reloadAction,false,true));
+      if (!Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+        hPanel->Add(Button::Create(_l(L"DLG_FILE_RELOAD",L"_Reload"),reloadAction,false,true));
+      }
 
       vPanel->Add(hPanel);
 
       if (OS::display->GetSize()<OS::Display::sizeNormal) {
-        vPanel->SetMinWidth(Base::Size::workVRel,80);
+        vPanel->SetMinHeight(Base::Size::workVRel,80);
       }
       else {
         vPanel->SetMinHeight(Base::Size::workVRel,60);
@@ -376,7 +393,9 @@ namespace Lum {
                             !showHidden->Get(),
                             options->mode==Options::modeDirectory);
 
-      table->GetTableView()->GetVAdjustment()->SetTop(1);
+      if (table->GetTableView()->GetVAdjustment()->IsValid()) {
+        table->GetTableView()->GetVAdjustment()->SetTop(1);
+      }
       dirList->On();
 
       if (dirList->GetRows()>0) {
@@ -525,18 +544,17 @@ namespace Lum {
           }
         }
       }
-      else {
-        if (entry.isDir) {
-          newPath.AppendDir(entry.name);
-          path->Set(newPath);
-        }
-        else {
-          if ((options->existingOnly && newPath.Exists() && !newPath.IsDir()) ||
-              !options->existingOnly) {
-            result=true;
-            Exit();
-          }
-        }
+      else if (!options->existingOnly) {
+        result=true;
+        Exit();
+      }
+      else if (entry.isDir) {
+        newPath.AppendDir(entry.name);
+        path->Set(newPath);
+      }
+      else if (options->existingOnly && newPath.Exists() && !newPath.IsDir()) {
+        result=true;
+        Exit();
       }
     }
 
@@ -672,6 +690,7 @@ namespace Lum {
       if (options==NULL) {
         options=new Options();
       }
+
       options->SetMode(Options::modeFile);
       options->SetExistingOnly(false);
 
@@ -707,6 +726,7 @@ namespace Lum {
       if (options==NULL) {
         options=new Options();
       }
+
       options->SetMode(Options::modeDirectory);
       options->SetExistingOnly(true);
 
