@@ -19,16 +19,17 @@
 
 #include <Lum/Dlg/Progress.h>
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/ButtonRow.h>
 #include <Lum/FuelGauge.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/Text.h>
 
 namespace Lum {
   namespace Dlg {
 
-    class Progress : public Dialog
+    class Progress : public ActionDialog
     {
     private:
       std::wstring     caption;
@@ -61,8 +62,7 @@ namespace Lum {
         if (captionText!=NULL) {
           captionText->SetText(caption,
                                OS::Font::italic|OS::Font::bold,Text::left,
-                               OS::display->GetFont(OS::Display::fontTypeProportional,
-                                                    OS::Display::fontScaleCaption1));
+                               OS::display->GetFont(OS::Display::fontScaleCaption1));
         }
       }
 
@@ -74,48 +74,43 @@ namespace Lum {
         }
       }
 
-      void PreInit()
+      Lum::Object* GetContent()
       {
         FuelGauge   *fuelGauge;
         Panel       *vPanel;
 
-        vPanel=new VPanel();
-        vPanel->SetFlex(true,false);
+        vPanel=VPanel::Create(true,false);
 
         captionText=new Text(caption,
                              OS::Font::italic|OS::Font::bold,Text::left,
-                             OS::display->GetFont(OS::Display::fontTypeProportional,
-                                                  OS::Display::fontScaleCaption1));
+                             OS::display->GetFont(OS::Display::fontScaleCaption1));
         captionText->SetFlex(true,false);
         captionText->SetMinWidth(Lum::Base::Size::pixel,
                                  Lum::Base::GetSize(Lum::Base::Size::stdCharWidth,30,
-                                                    OS::display->GetFont(OS::Display::fontTypeProportional,
-                                                                         OS::Display::fontScaleCaption1)));
+                                                    OS::display->GetFont(OS::Display::fontScaleCaption1)));
         vPanel->Add(captionText);
-
-        vPanel->Add(new VSpace());
+        vPanel->AddSpace();
 
         actionText=new Text();
         actionText->SetFlex(true,false);
         actionText->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
         actionText->SetText(action);
         vPanel->Add(actionText);
-
-        vPanel->Add(new VSpace());
+        vPanel->AddSpace();
 
         fuelGauge=new FuelGauge();
         fuelGauge->SetFlex(true,false);
         fuelGauge->SetModel(percent);
         vPanel->Add(fuelGauge);
 
+        return vPanel;
+      }
+
+      void GetActions(std::vector<ActionInfo>& actions)
+      {
         if (abortAction.Valid()) {
-          vPanel->Add(new VSpace());
-          vPanel->Add(ButtonRow::CreateCancel(abortAction));
+          CreateActionInfosCancel(actions,abortAction);
         }
-
-        SetMain(vPanel);
-
-        Dialog::PreInit();
       }
 
       void Resync(Base::Model* model, const Base::ResyncMsg& msg)
@@ -125,7 +120,7 @@ namespace Lum {
           abortAction->Trigger();
         }
 
-        Dialog::Resync(model,msg);
+        ActionDialog::Resync(model,msg);
       }
     };
 
