@@ -228,7 +228,7 @@ namespace Lum {
 
       while (scanner->GetNext(entry,status)) {
         if ((!noHiddenFiles || (noHiddenFiles && !(entry.isHidden))) &&
-            (!onlyDirs || (onlyDirs && !(entry.isDir))) &&
+            (!onlyDirs || (onlyDirs && entry.isDir)) &&
             entry.name!=L"." && entry.name!=L"..") {
           if (entry.isDir || filter==NULL || filter->Match(directory,entry)) {
             content.push_back(entry);
