@@ -180,7 +180,7 @@ namespace Lum {
 
     GMainLoopEventLoop::GMainLoopEventLoop()
     {
-      context=g_main_context_new();
+      context=g_main_context_default();//g_main_context_new();
 
       //AddSource(new AsyncActionsEventSource(this));
     }
@@ -218,6 +218,7 @@ namespace Lum {
         }
 
         g_source_add_poll((GSource*)gSource,&gSource->poll);
+        g_source_set_priority((GSource*)gSource,-100);
         g_source_set_can_recurse((GSource*)gSource,true);
       }
 
