@@ -399,7 +399,19 @@ namespace Lum {
         return drawsDisabled|drawsFocused|drawsActivated;
       }
 
-      void ThemeImage::Draw(Lum::OS::DrawInfo *draw, int x, int y, size_t w, size_t h)
+      void ThemeImage::Draw(OS::DrawInfo *draw, int x, int y)
+      {
+        DrawStretched(draw,x,y,GetWidth(),GetHeight());
+      }
+
+      void ThemeImage::DrawScaled(OS::DrawInfo *draw, int x, int y, size_t w, size_t h)
+      {
+        // We cannot scale images
+        std::cerr << "Image of type " << image << " cannot be scaled!" << std::endl;
+        assert(false);
+      }
+
+      void ThemeImage::DrawStretched(Lum::OS::DrawInfo *draw, int x, int y, size_t w, size_t h)
       {
         HDC  dc=dynamic_cast<DrawInfo*>(draw)->dc;
         RECT rect;
@@ -858,7 +870,7 @@ namespace Lum {
             draw->PopPen();
           }
           break;
-#endif          
+#endif
         case Display::radioImageIndex:
           if (HasTheming()) {
             if (draw->selected) {
@@ -1496,7 +1508,7 @@ namespace Lum {
             rect.top=yOff;
             rect.right=xOff+width;
             rect.bottom=yOff+height;
-	
+
             /* ignore */ DrawFrameControl(dc,
                                           &rect,
                                           DFC_BUTTON,
@@ -1504,9 +1516,9 @@ namespace Lum {
             return;
           }
           break;
-				case Display::editComboBackgroundFillIndex:
+                case Display::editComboBackgroundFillIndex:
           if (HasTheming()) {
-	          return;
+              return;
           }
           else {
             rect.left=xOff;
@@ -1515,9 +1527,9 @@ namespace Lum {
             rect.bottom=yOff+height;
 
             /* ignore */ DrawEdge(dc,&rect,EDGE_SUNKEN,BF_RECT);
-				    return;
-			    }
-					break;
+                    return;
+                }
+                    break;
         case Display::toolbarButtonBackgroundFillIndex:
           if (HasTheming()) {
             RECT content,clip;
@@ -1596,20 +1608,20 @@ namespace Lum {
             /* ignore */ DrawEdge(dc,&rect,EDGE_SUNKEN,BF_RECT);
           }
 
-  	      if (draw->selected) {
-	          if (draw->focused) {
-	            brush=::GetSysColorBrush(COLOR_HIGHLIGHT);
-	          }
-	          else {
-	          brush=::GetSysColorBrush(COLOR_BTNFACE);
-	          }
-	        }
+          if (draw->selected) {
+              if (draw->focused) {
+                brush=::GetSysColorBrush(COLOR_HIGHLIGHT);
+              }
+              else {
+              brush=::GetSysColorBrush(COLOR_BTNFACE);
+              }
+            }
           else {
-	          brush=::GetSysColorBrush(COLOR_WINDOW);
-	        }
-	
-	        rect.left=xOff+leftBorder;
-    	    rect.top=yOff+topBorder;
+              brush=::GetSysColorBrush(COLOR_WINDOW);
+            }
+
+            rect.left=xOff+leftBorder;
+            rect.top=yOff+topBorder;
           rect.right=xOff+width-leftBorder-rightBorder+2;
           rect.bottom=yOff+height-topBorder-bottomBorder+2;
 
@@ -1820,7 +1832,7 @@ namespace Lum {
           break;
         case Display::tabBackgroundFillIndex:
           if (HasTheming()) {
-	        FillRect(dc,&rect,::GetSysColorBrush(COLOR_INFOBK));
+            FillRect(dc,&rect,::GetSysColorBrush(COLOR_INFOBK));
 
             RECT content,extent,clip;
 
