@@ -55,19 +55,6 @@ namespace Lum {
     }
   }
 
-  bool PopupControl::VisitChildren(Visitor &visitor, bool onlyVisible)
-  {
-    if (control!=NULL && !visitor.Visit(control)) {
-      return false;
-    }
-
-    if (button!=NULL && !visitor.Visit(button)) {
-      return false;
-    }
-
-    return true;
-  }
-
   bool PopupControl::SetModel(Base::Model* model)
   {
     bool res;
